package models

// 设备关联表 将设备类型、ID 和 机号、分区、分组关联
type Device struct {
	ID             int64  `gorm:"column:id" json:"id"`
	OrgID          int64  `gorm:"column:org_id" json:"-"`
	DeviceType     int8   `json:"device_type"`                                     // 设备类型 1.透析机 2.水处理机
	DMID           int64  `gorm:"column:dm_id" json:"-"`                           // 透析机 id（type = 1时）
	WTEID          int64  `gorm:"column:wte_id" json:"-"`                          // 水处理机 id（type = 2时）
	SerialNumber   string `json:"serial_number"`                                   // 序列号
	Name           string `json:"name"`                                            // 设备名
	Model          string `json:"model"`                                           // 型号
	DeviceNumberID int64  `gorm:"column:device_number_id" json:"device_number_id"` // 机号
	DeviceNumber   string `json:"device_number"`                                   // 机号名
	DeviceZoneID   int64  `gorm:"column:device_zone_id" json:"device_zone_id"`     // 分区
	DeviceGroupID  int64  `gorm:"column:device_group_id" json:"device_group_id"`   // 分组
	Status         int8   `json:"-"`
	CreateTime     int64  `gorm:"column:ctime" json:"-"`
	ModifyTime     int64  `gorm:"column:mtime" json:"-"`
}

func (Device) TableName() string {
	return "xt_device"
}

// 透析机
type DeviceDM struct {
	ID                int64  `gorm:"column:id" json:"id"`
	OrgID             int64  `gorm:"column:org_id" json:"-"`
	SerialNumber      string `json:"serial_number"`      // 序列号
	Name              string `json:"name"`               // 设备名
	Manufacturer      string `json:"manufacturer"`       // 生产厂家
	RepairFactory     string `json:"repair_factory"`     // 维修厂家
	Model             string `json:"model"`              // 型号
	Department        string `json:"department"`         // 使用科室
	DepartmentNumber  string `json:"department_number"`  // 科室编号
	PurchaseDate      int64  `json:"purchase_date"`      // 购买日期
	InstallDate       int64  `json:"install_date"`       // 安装日期
	CommissioningDate int64  `json:"commissioning_date"` // 启用日期
	Maintainer        string `json:"maintainer"`         // 维修工程师
	MaintenanceCall   string `json:"maintenance_call"`   // 维修联系电话
	WarrantyPeriod    string `json:"warranty_period"`    // 保修期限
	DeviceStatus      int    `json:"device_status"`      // 机器状态 1.使用机 2.备用机 3.急诊机 4.报废机
	InitialUseTimes   int    `json:"initial_use_times"`  // 初始使用次数
	Mark              string `json:"mark"`               // 备注
	RetirementDate    int64  `json:"retirement_date"`    // 报废日期
	RetirementReason  string `json:"retirement_reason"`  // 报废原因
	ServiceLife       int    `json:"service_life"`       // 使用年限
	WorkingTime       int    `json:"working_time"`       // 工作时长
	TreatmentMode     string `json:"treatment_mode"`     // 治疗模式
	Status            int8   `json:"-"`
	CreateTime        int64  `gorm:"column:ctime" json:"-"`
	ModifyTime        int64  `gorm:"column:mtime" json:"-"`
}

func (DeviceDM) TableName() string {
	return "xt_device_info_dm"
}

// 水处理机
type DeviceWTE struct {
	ID                 int64  `gorm:"column:id" json:"id"`
	OrgID              int64  `gorm:"column:org_id" json:"-"`
	SerialNumber       string `json:"serial_number"`        // 序列号
	Name               string `json:"name"`                 // 设备名
	Manufacturer       string `json:"manufacturer"`         // 生产厂家
	RepairFactory      string `json:"repair_factory"`       // 维修厂家
	Model              string `json:"model"`                // 型号
	Department         string `json:"department"`           // 使用科室
	DepartmentNumber   string `json:"department_number"`    // 科室编号
	PurchaseDate       int64  `json:"purchase_date"`        // 购买日期
	InstallDate        int64  `json:"install_date"`         // 安装日期
	CommissioningDate  int64  `json:"commissioning_date"`   // 启用日期
	Maintainer         string `json:"maintainer"`           // 维修工程师
	MaintenanceCall    string `json:"maintenance_call"`     // 维修联系电话
	WarrantyPeriod     string `json:"warranty_period"`      // 保修期限
	DeviceStatus       int    `json:"device_status"`        // 机器状态 1.使用机 2.备用机 3.急诊机 4.报废机
	InitialUseTimes    int    `json:"initial_use_times"`    // 初始使用次数
	Mark               string `json:"mark"`                 // 备注
	RetirementDate     int64  `json:"retirement_date"`      // 报废日期
	RetirementReason   string `json:"retirement_reason"`    // 报废原因
	ServiceLife        int    `json:"service_life"`         // 使用年限
	WorkingTime        int    `json:"working_time"`         // 工作时长
	ReverseOsmosisMode int    `json:"reverse_osmosis_mode"` // 反渗模式
	Status             int8   `json:"-"`
	CreateTime         int64  `gorm:"column:ctime" json:"-"`
	ModifyTime         int64  `gorm:"column:mtime" json:"-"`
}

func (DeviceWTE) TableName() string {
	return "xt_device_info_wte"
}

type DeviceZones struct {
	ID         int64  `gorm:"column:id" json:"id"`
	OrgID      int64  `gorm:"column:org_id" json:"-"`
	Name       string `json:"name"`
	Type       int    `json:"type"`
	Status     int8   `json:"-"`
	CreateTime int64  `gorm:"column:ctime" json:"-"`
	ModifyTime int64  `gorm:"column:mtime" json:"-"`
	Number     string `gorm:"column:number" json:"number" form:"number"`
}

type DeviceZone struct {
	ID         int64  `gorm:"column:id" json:"id"`
	OrgID      int64  `gorm:"column:org_id" json:"-"`
	Name       string `json:"name"`
	Type       int    `json:"type"`
	Status     int8   `json:"-"`
	CreateTime int64  `gorm:"column:ctime" json:"-"`
	ModifyTime int64  `gorm:"column:mtime" json:"-"`
}

func (DeviceZone) TableName() string {
	return "xt_device_zone"
}

type DeviceGroups struct {
	ID         int64  `gorm:"column:id" json:"id"`
	OrgID      int64  `gorm:"column:org_id" json:"-"`
	Name       string `json:"name"`
	Status     int8   `json:"-"`
	CreateTime int64  `gorm:"column:ctime" json:"-"`
	ModifyTime int64  `gorm:"column:mtime" json:"-"`
	Number     string `gorm:"column:number" json:"number" form:"number"`
}

type DeviceGroup struct {
	ID         int64  `gorm:"column:id" json:"id"`
	OrgID      int64  `gorm:"column:org_id" json:"-"`
	Name       string `json:"name"`
	Status     int8   `json:"-"`
	CreateTime int64  `gorm:"column:ctime" json:"-"`
	ModifyTime int64  `gorm:"column:mtime" json:"-"`
}

func (DeviceGroup) TableName() string {
	return "xt_device_group"
}

type DeviceNumber struct {
	ID         int64  `gorm:"column:id" json:"id"`
	OrgID      int64  `gorm:"column:org_id" json:"-"`
	Number     string `gorm:"column:number" json:"number"`
	GroupID    int64  `gorm:"column:group_id" json:"group_id"`
	ZoneID     int64  `gorm:"column:zone_id" json:"zone_id"`
	Status     int8   `json:"-"`
	CreateTime int64  `gorm:"column:ctime" json:"-"`
	ModifyTime int64  `gorm:"column:mtime" json:"-"`
	Sort       int64  `gorm:"column:sort" json:"sort" form:"sort"`
}

func (DeviceNumber) TableName() string {
	return "xt_device_number"
}

type XtDeviceNumber struct {
	ID      int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	OrgId   int64  `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Number  string `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	GroupId int64  `gorm:"column:group_id" json:"group_id" form:"group_id"`
	ZoneId  int64  `gorm:"column:zone_id" json:"zone_id" form:"zone_id"`
	Status  int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime   int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime   int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
}

func (XtDeviceNumber) TableName() string {
	return "xt_device_number"
}

type DeviceAddmachers struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	SerialNumber        string `gorm:"column:serial_number" json:"serial_number" form:"serial_number"`
	DeviceType          int64  `gorm:"column:device_type" json:"device_type" form:"device_type"`
	BedNumber           string `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	DeviceName          string `gorm:"column:device_name" json:"device_name" form:"device_name"`
	ManufactureFactory  string `gorm:"column:manufacture_factory" json:"manufacture_factory" form:"manufacture_factory"`
	ServiceManufacturer string `gorm:"column:service_manufacturer" json:"service_manufacturer" form:"service_manufacturer"`
	UnitType            string `gorm:"column:unit_type" json:"unit_type" form:"unit_type"`
	UseSection          string `gorm:"column:use_section" json:"use_section" form:"use_section"`
	SectionNumber       string `gorm:"column:section_number" json:"section_number" form:"section_number"`
	BuyDate             int64  `gorm:"column:buy_date" json:"buy_date" form:"buy_date"`
	InstallDate         int64  `gorm:"column:install_date" json:"install_date" form:"install_date"`
	StartDate           int64  `gorm:"column:start_date" json:"start_date" form:"start_date"`
	MaintenaceEngineer  string `gorm:"column:maintenace_engineer" json:"maintenace_engineer" form:"maintenace_engineer"`
	Telephone           string `gorm:"column:telephone" json:"telephone" form:"telephone"`
	GuaranteeDate       string `gorm:"column:guarantee_date" json:"guarantee_date" form:"guarantee_date"`
	MachineStatus       int64  `gorm:"column:machine_status" json:"machine_status" form:"machine_status"`
	UserTotal           string `gorm:"column:user_total" json:"user_total" form:"user_total"`
	DisinfectionMode    int64  `gorm:"column:disinfection_mode" json:"disinfection_mode" form:"disinfection_mode"`
	Remarks             string `gorm:"column:remarks" json:"remarks" form:"remarks"`
	RubbishDate         int64  `gorm:"column:rubbish_date" json:"rubbish_date" form:"rubbish_date"`
	RubbishReason       int64  `gorm:"column:rubbish_reason" json:"rubbish_reason" form:"rubbish_reason"`
	UserYear            string `gorm:"column:user_year" json:"user_year" form:"user_year"`
	WorkTime            string `gorm:"column:work_time" json:"work_time" form:"work_time"`
	ReversMode          int64  `gorm:"column:revers_mode" json:"revers_mode" form:"revers_mode"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	ZoneId              int64  `gorm:"column:zone_id" json:"zone_id" form:"zone_id"`
	Name                string `gorm:"column:name" json:"name" form:"name"`
	EquitmentName       string `gorm:"column:equitment_name" json:"equitment_name" form:"equitment_name"`
	BedId               int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	DeviceMode          string `gorm:"column:device_mode" json:"device_mode" form:"device_mode"`
	Number              string `gorm:"column:number" json:"number" form:"number"`
	EquimentId          int64  `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
}

type DeviceAddmacher struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	SerialNumber        string `gorm:"column:serial_number" json:"serial_number" form:"serial_number"`
	DeviceType          int64  `gorm:"column:device_type" json:"device_type" form:"device_type"`
	BedNumber           string `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	DeviceName          string `gorm:"column:device_name" json:"device_name" form:"device_name"`
	ManufactureFactory  string `gorm:"column:manufacture_factory" json:"manufacture_factory" form:"manufacture_factory"`
	ServiceManufacturer string `gorm:"column:service_manufacturer" json:"service_manufacturer" form:"service_manufacturer"`
	UnitType            int64  `gorm:"column:unit_type" json:"unit_type" form:"unit_type"`
	UseSection          string `gorm:"column:use_section" json:"use_section" form:"use_section"`
	SectionNumber       string `gorm:"column:section_number" json:"section_number" form:"section_number"`
	BuyDate             int64  `gorm:"column:buy_date" json:"buy_date" form:"buy_date"`
	InstallDate         int64  `gorm:"column:install_date" json:"install_date" form:"install_date"`
	StartDate           int64  `gorm:"column:start_date" json:"start_date" form:"start_date"`
	MaintenaceEngineer  string `gorm:"column:maintenace_engineer" json:"maintenace_engineer" form:"maintenace_engineer"`
	Telephone           string `gorm:"column:telephone" json:"telephone" form:"telephone"`
	GuaranteeDate       string `gorm:"column:guarantee_date" json:"guarantee_date" form:"guarantee_date"`
	MachineStatus       int64  `gorm:"column:machine_status" json:"machine_status" form:"machine_status"`
	UserTotal           string `gorm:"column:user_total" json:"user_total" form:"user_total"`
	DisinfectionMode    int64  `gorm:"column:disinfection_mode" json:"disinfection_mode" form:"disinfection_mode"`
	Remarks             string `gorm:"column:remarks" json:"remarks" form:"remarks"`
	RubbishDate         int64  `gorm:"column:rubbish_date" json:"rubbish_date" form:"rubbish_date"`
	RubbishReason       int64  `gorm:"column:rubbish_reason" json:"rubbish_reason" form:"rubbish_reason"`
	UserYear            string `gorm:"column:user_year" json:"user_year" form:"user_year"`
	WorkTime            string `gorm:"column:work_time" json:"work_time" form:"work_time"`
	ReversMode          int64  `gorm:"column:revers_mode" json:"revers_mode" form:"revers_mode"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	ZoneId              int64  `gorm:"column:zone_id" json:"zone_id" form:"zone_id"`
	BedId               int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
}

func (DeviceAddmacher) TableName() string {
	return "xt_device_addmacher"
}

type DeviceTreatmentmode struct {
	ID         int64 `gorm:"column:id" json:"id" form:"id"`
	MachineId  int64 `gorm:"column:machine_id" json:"machine_id" form:"machine_id"`
	Status     int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime      int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime      int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId  int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	TreateMode int64 `gorm:"column:treate_mode" json:"treate_mode" form:"treate_mode"`
}

func (DeviceTreatmentmode) TableName() string {
	return "xt_device_treatmentmode"
}

type XtDeviceMachine struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	SerialNumber        int64  `gorm:"column:serial_number" json:"serial_number" form:"serial_number"`
	DeviceType          int64  `gorm:"column:device_type" json:"device_type" form:"device_type"`
	BedNumber           string `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	DeviceName          string `gorm:"column:device_name" json:"device_name" form:"device_name"`
	ManufactureFactory  string `gorm:"column:manufacture_factory" json:"manufacture_factory" form:"manufacture_factory"`
	ServiceManufacturer string `gorm:"column:service_manufacturer" json:"service_manufacturer" form:"service_manufacturer"`
	UnitType            string `gorm:"column:unit_type" json:"unit_type" form:"unit_type"`
	UseSection          string `gorm:"column:use_section" json:"use_section" form:"use_section"`
	SectionNumber       string `gorm:"column:section_number" json:"section_number" form:"section_number"`
	BuyDate             int64  `gorm:"column:buy_date" json:"buy_date" form:"buy_date"`
	InstallDate         int64  `gorm:"column:install_date" json:"install_date" form:"install_date"`
	StartDate           int64  `gorm:"column:start_date" json:"start_date" form:"start_date"`
	MaintenaceEngineer  string `gorm:"column:maintenace_engineer" json:"maintenace_engineer" form:"maintenace_engineer"`
	Telephone           string `gorm:"column:telephone" json:"telephone" form:"telephone"`
	GuaranteeDate       string `gorm:"column:guarantee_date" json:"guarantee_date" form:"guarantee_date"`
	MachineStatus       int64  `gorm:"column:machine_status" json:"machine_status" form:"machine_status"`
	UserTotal           string `gorm:"column:user_total" json:"user_total" form:"user_total"`
	DisinfectionMode    int64  `gorm:"column:disinfection_mode" json:"disinfection_mode" form:"disinfection_mode"`
	Remarks             string `gorm:"column:remarks" json:"remarks" form:"remarks"`
	RubbishDate         int64  `gorm:"column:rubbish_date" json:"rubbish_date" form:"rubbish_date"`
	RubbishReason       int64  `gorm:"column:rubbish_reason" json:"rubbish_reason" form:"rubbish_reason"`
	UserYear            string `gorm:"column:user_year" json:"user_year" form:"user_year"`
	WorkTime            string `gorm:"column:work_time" json:"work_time" form:"work_time"`
	ReversMode          int64  `gorm:"column:revers_mode" json:"revers_mode" form:"revers_mode"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	ZoneId              int64  `gorm:"column:zone_id" json:"zone_id" form:"zone_id"`
	BedId               int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
}

func (XtDeviceMachine) TableName() string {
	return "xt_device_machine"
}

type DeviceEquimentname struct {
	ID            int64  `gorm:"column:id" json:"id" form:"id"`
	EquitmentName string `gorm:"column:equitment_name" json:"equitment_name" form:"equitment_name"`
	Status        int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime         int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime         int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId     int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquitmentId   int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	BedId         int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
}

func (DeviceEquimentname) TableName() string {

	return "xt_device_equimentname"
}

type DevicePlanss struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	DeviceType          int64  `gorm:"column:device_type" json:"device_type" form:"device_type"`
	DisinfecTime        int64  `gorm:"column:disinfec_time" json:"disinfec_time" form:"disinfec_time"`
	Time                int64  `gorm:"column:time" json:"time" form:"time"`
	Classtime           int64  `gorm:"column:classtime" json:"classtime" form:"classtime"`
	Way                 int64  `gorm:"column:way" json:"way" form:"way"`
	MachineDisinfectant int64  `gorm:"column:machine_disinfectant" json:"machine_disinfectant" form:"machine_disinfectant"`
	DisinfectanWay      int64  `gorm:"column:disinfectan_way" json:"disinfectan_way" form:"disinfectan_way"`
	Disinfectant        int64  `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId          int64  `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	EquitmentName       string `gorm:"column:equitment_name" json:"equitment_name" form:"equitment_name"`
}

type DevicePlans struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	DeviceType          int64  `gorm:"column:device_type" json:"device_type" form:"device_type"`
	DisinfecTime        int64  `gorm:"column:disinfec_time" json:"disinfec_time" form:"disinfec_time"`
	Time                int64  `gorm:"column:time" json:"time" form:"time"`
	Classtime           int64  `gorm:"column:classtime" json:"classtime" form:"classtime"`
	Way                 int64  `gorm:"column:way" json:"way" form:"way"`
	MachineDisinfectant int64  `gorm:"column:machine_disinfectant" json:"machine_disinfectant" form:"machine_disinfectant"`
	DisinfectanWay      int64  `gorm:"column:disinfectan_way" json:"disinfectan_way" form:"disinfectan_way"`
	Disinfectant        int64  `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId          int64  `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	DeviceMode          string `gorm:"column:device_mode" json:"device_mode" form:"device_mode"`
}

type DevicePlan struct {
	ID                  int64 `gorm:"column:id" json:"id" form:"id"`
	DeviceType          int64 `gorm:"column:device_type" json:"device_type" form:"device_type"`
	DisinfecTime        int64 `gorm:"column:disinfec_time" json:"disinfec_time" form:"disinfec_time"`
	Time                int64 `gorm:"column:time" json:"time" form:"time"`
	Classtime           int64 `gorm:"column:classtime" json:"classtime" form:"classtime"`
	Way                 int64 `gorm:"column:way" json:"way" form:"way"`
	MachineDisinfectant int64 `gorm:"column:machine_disinfectant" json:"machine_disinfectant" form:"machine_disinfectant"`
	DisinfectanWay      int64 `gorm:"column:disinfectan_way" json:"disinfectan_way" form:"disinfectan_way"`
	Disinfectant        int64 `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	Status              int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime               int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime               int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId           int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId          int64 `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	BedId               int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
}

func (DevicePlan) TableName() string {

	return "xt_device_plan"
}

type Schedules struct {
	ID           int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64  `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64  `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64  `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64  `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64  `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64  `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64  `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64  `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	Name         string `gorm:"column:name" json:"name" form:"name"`
	IsInfectious int64  `gorm:"column:is_infectious" json:"is_infectious"`
}

type XtSchedule struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
}

func (XtSchedule) TableName() string {

	return "xt_schedule"
}

type DeviceInformationss struct {
	ID                    int64  `gorm:"column:id" json:"id" form:"id"`
	Date                  int64  `gorm:"column:date" json:"date" form:"date"`
	Class                 int64  `gorm:"column:class" json:"class" form:"class"`
	Zone                  int64  `gorm:"column:zone" json:"zone" form:"zone"`
	BedNumber             int64  `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	PatientId             int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Contagion             string `gorm:"column:contagion" json:"contagion" form:"contagion"`
	DialysisMode          int64  `gorm:"column:dialysis_mode" json:"dialysis_mode" form:"dialysis_mode"`
	StartTime             int64  `gorm:"column:start_time" json:"start_time" form:"start_time"`
	EndTime               int64  `gorm:"column:end_time" json:"end_time" form:"end_time"`
	DialysisHour          string `gorm:"column:dialysis_hour" json:"dialysis_hour" form:"dialysis_hour"`
	Hyperfiltratio        string `gorm:"column:hyperfiltratio" json:"hyperfiltratio" form:"hyperfiltratio"`
	WeightLoss            string `gorm:"column:weight_loss" json:"weight_loss" form:"weight_loss"`
	WarningValue          string `gorm:"column:warning_value" json:"warning_value" form:"warning_value"`
	UserTotal             string `gorm:"column:user_total" json:"user_total" form:"user_total"`
	Move                  int64  `gorm:"column:move" json:"move" form:"move"`
	FailureStage          int64  `gorm:"column:failure_stage" json:"failure_stage" form:"failure_stage"`
	FaultDescription      string `gorm:"column:fault_description" json:"fault_description" form:"fault_description"`
	CodeInformation       string `gorm:"column:code_information" json:"code_information" form:"code_information"`
	DisinfectType         int64  `gorm:"column:disinfect_type" json:"disinfect_type" form:"disinfect_type"`
	DisinfectantType      int64  `gorm:"column:disinfectant_type" json:"disinfectant_type" form:"disinfectant_type"`
	Disinfection          int64  `gorm:"column:disinfection" json:"disinfection" form:"disinfection"`
	MachineRun            int64  `gorm:"column:machine_run" json:"machine_run" form:"machine_run"`
	FluidPath             int64  `gorm:"column:fluid_path" json:"fluid_path" form:"fluid_path"`
	Disinfectant          int64  `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	DisinfectionStatus    int64  `gorm:"column:disinfection_status" json:"disinfection_status" form:"disinfection_status"`
	DisinfectionResidue   int64  `gorm:"column:disinfection_residue" json:"disinfection_residue" form:"disinfection_residue"`
	LongTime              string `gorm:"column:long_time" json:"long_time" form:"long_time"`
	DisinfecStartime      int64  `gorm:"column:disinfec_startime" json:"disinfec_startime" form:"disinfec_startime"`
	DisinfecEndtime       int64  `gorm:"column:disinfec_endtime" json:"disinfec_endtime" form:"disinfec_endtime"`
	DialysisChecked       int64  `gorm:"column:dialysis_checked" json:"dialysis_checked" form:"dialysis_checked"`
	DialysisName          int64  `gorm:"column:dialysis_name" json:"dialysis_name" form:"dialysis_name"`
	Norms                 string `gorm:"column:norms" json:"norms" form:"norms"`
	DialysisConcentration int64  `gorm:"column:dialysis_concentration" json:"dialysis_concentration" form:"dialysis_concentration"`
	GermChecked           int64  `gorm:"column:germ_checked" json:"germ_checked" form:"germ_checked"`
	GermName              int64  `gorm:"column:germ_name" json:"germ_name" form:"germ_name"`
	GermNumber            string `gorm:"column:germ_number" json:"germ_number" form:"germ_number"`
	Clean                 int64  `gorm:"column:clean" json:"clean" form:"clean"`
	SignName              int64  `gorm:"column:sign_name" json:"sign_name" form:"sign_name"`
	Status                int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime                 int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                 int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId             int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId            int64  `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	Name                  string `gorm:"column:name" json:"name" form:"name"`
	UserName              string `gorm:"column:user_name" json:"user_name" form:"user_name"`
}

type DeviceInformations struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	Date                  int64   `gorm:"column:date" json:"date" form:"date"`
	Class                 int64   `gorm:"column:class" json:"class" form:"class"`
	Zone                  int64   `gorm:"column:zone" json:"zone" form:"zone"`
	BedNumber             int64   `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Contagion             string  `gorm:"column:contagion" json:"contagion" form:"contagion"`
	DialysisMode          int64   `gorm:"column:dialysis_mode" json:"dialysis_mode" form:"dialysis_mode"`
	StartTime             int64   `gorm:"column:start_time" json:"start_time" form:"start_time"`
	EndTime               int64   `gorm:"column:end_time" json:"end_time" form:"end_time"`
	DialysisHour          string  `gorm:"column:dialysis_hour" json:"dialysis_hour" form:"dialysis_hour"`
	Hyperfiltratio        float64 `gorm:"column:hyperfiltratio" json:"hyperfiltratio" form:"hyperfiltratio"`
	WeightLoss            float64 `gorm:"column:weight_loss" json:"weight_loss" form:"weight_loss"`
	WarningValue          string  `gorm:"column:warning_value" json:"warning_value" form:"warning_value"`
	UserTotal             string  `gorm:"column:user_total" json:"user_total" form:"user_total"`
	Move                  int64   `gorm:"column:move" json:"move" form:"move"`
	FailureStage          int64   `gorm:"column:failure_stage" json:"failure_stage" form:"failure_stage"`
	FaultDescription      string  `gorm:"column:fault_description" json:"fault_description" form:"fault_description"`
	CodeInformation       string  `gorm:"column:code_information" json:"code_information" form:"code_information"`
	DisinfectType         int64   `gorm:"column:disinfect_type" json:"disinfect_type" form:"disinfect_type"`
	DisinfectantType      int64   `gorm:"column:disinfectant_type" json:"disinfectant_type" form:"disinfectant_type"`
	Disinfection          int64   `gorm:"column:disinfection" json:"disinfection" form:"disinfection"`
	MachineRun            int64   `gorm:"column:machine_run" json:"machine_run" form:"machine_run"`
	FluidPath             int64   `gorm:"column:fluid_path" json:"fluid_path" form:"fluid_path"`
	Disinfectant          int64   `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	DisinfectionStatus    int64   `gorm:"column:disinfection_status" json:"disinfection_status" form:"disinfection_status"`
	DisinfectionResidue   int64   `gorm:"column:disinfection_residue" json:"disinfection_residue" form:"disinfection_residue"`
	LongTime              string  `gorm:"column:long_time" json:"long_time" form:"long_time"`
	DisinfecStartime      int64   `gorm:"column:disinfec_startime" json:"disinfec_startime" form:"disinfec_startime"`
	DisinfecEndtime       int64   `gorm:"column:disinfec_endtime" json:"disinfec_endtime" form:"disinfec_endtime"`
	DialysisChecked       int64   `gorm:"column:dialysis_checked" json:"dialysis_checked" form:"dialysis_checked"`
	DialysisName          int64   `gorm:"column:dialysis_name" json:"dialysis_name" form:"dialysis_name"`
	Norms                 string  `gorm:"column:norms" json:"norms" form:"norms"`
	DialysisConcentration int64   `gorm:"column:dialysis_concentration" json:"dialysis_concentration" form:"dialysis_concentration"`
	GermChecked           int64   `gorm:"column:germ_checked" json:"germ_checked" form:"germ_checked"`
	GermName              int64   `gorm:"column:germ_name" json:"germ_name" form:"germ_name"`
	GermNumber            string  `gorm:"column:germ_number" json:"germ_number" form:"germ_number"`
	Clean                 int64   `gorm:"column:clean" json:"clean" form:"clean"`
	SignName              int64   `gorm:"column:sign_name" json:"sign_name" form:"sign_name"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	Ctime                 int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                 int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId            int64   `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	Bed                   string  `gorm:"column:bed" json:"bed" form:"bed"`
	Name                  string  `gorm:"column:name" json:"name" form:"name"`
	UserName              string  `gorm:"column:user_name" json:"user_name" form:"user_name"`
	AdminUserId           int64   `gorm:"column:admin_user_id" json:"admin_user_id"`
}

type DeviceInformation struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	Date                  int64   `gorm:"column:date" json:"date" form:"date"`
	Class                 int64   `gorm:"column:class" json:"class" form:"class"`
	Zone                  int64   `gorm:"column:zone" json:"zone" form:"zone"`
	BedNumber             int64   `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Contagion             string  `gorm:"column:contagion" json:"contagion" form:"contagion"`
	DialysisMode          int64   `gorm:"column:dialysis_mode" json:"dialysis_mode" form:"dialysis_mode"`
	StartTime             int64   `gorm:"column:start_time" json:"start_time" form:"start_time"`
	EndTime               int64   `gorm:"column:end_time" json:"end_time" form:"end_time"`
	DialysisHour          string  `gorm:"column:dialysis_hour" json:"dialysis_hour" form:"dialysis_hour"`
	Hyperfiltratio        float64 `gorm:"column:hyperfiltratio" json:"hyperfiltratio" form:"hyperfiltratio"`
	WeightLoss            float64 `gorm:"column:weight_loss" json:"weight_loss" form:"weight_loss"`
	WarningValue          string  `gorm:"column:warning_value" json:"warning_value" form:"warning_value"`
	UserTotal             string  `gorm:"column:user_total" json:"user_total" form:"user_total"`
	Move                  int64   `gorm:"column:move" json:"move" form:"move"`
	FailureStage          int64   `gorm:"column:failure_stage" json:"failure_stage" form:"failure_stage"`
	FaultDescription      string  `gorm:"column:fault_description" json:"fault_description" form:"fault_description"`
	CodeInformation       string  `gorm:"column:code_information" json:"code_information" form:"code_information"`
	DisinfectType         int64   `gorm:"column:disinfect_type" json:"disinfect_type" form:"disinfect_type"`
	DisinfectantType      int64   `gorm:"column:disinfectant_type" json:"disinfectant_type" form:"disinfectant_type"`
	Disinfection          int64   `gorm:"column:disinfection" json:"disinfection" form:"disinfection"`
	MachineRun            int64   `gorm:"column:machine_run" json:"machine_run" form:"machine_run"`
	FluidPath             int64   `gorm:"column:fluid_path" json:"fluid_path" form:"fluid_path"`
	Disinfectant          int64   `gorm:"column:disinfectant" json:"disinfectant" form:"disinfectant"`
	DisinfectionStatus    int64   `gorm:"column:disinfection_status" json:"disinfection_status" form:"disinfection_status"`
	DisinfectionResidue   int64   `gorm:"column:disinfection_residue" json:"disinfection_residue" form:"disinfection_residue"`
	LongTime              string  `gorm:"column:long_time" json:"long_time" form:"long_time"`
	DisinfecStartime      int64   `gorm:"column:disinfec_startime" json:"disinfec_startime" form:"disinfec_startime"`
	DisinfecEndtime       int64   `gorm:"column:disinfec_endtime" json:"disinfec_endtime" form:"disinfec_endtime"`
	DialysisChecked       int64   `gorm:"column:dialysis_checked" json:"dialysis_checked" form:"dialysis_checked"`
	DialysisName          int64   `gorm:"column:dialysis_name" json:"dialysis_name" form:"dialysis_name"`
	Norms                 string  `gorm:"column:norms" json:"norms" form:"norms"`
	DialysisConcentration int64   `gorm:"column:dialysis_concentration" json:"dialysis_concentration" form:"dialysis_concentration"`
	GermChecked           int64   `gorm:"column:germ_checked" json:"germ_checked" form:"germ_checked"`
	GermName              int64   `gorm:"column:germ_name" json:"germ_name" form:"germ_name"`
	GermNumber            string  `gorm:"column:germ_number" json:"germ_number" form:"germ_number"`
	Clean                 int64   `gorm:"column:clean" json:"clean" form:"clean"`
	SignName              int64   `gorm:"column:sign_name" json:"sign_name" form:"sign_name"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	Ctime                 int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                 int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquimentId            int64   `gorm:"column:equiment_id" json:"equiment_id" form:"equiment_id"`
	Bed                   string  `gorm:"column:bed" json:"bed" form:"bed"`
	Stime                 int64   `gorm:"column:stime" json:"stime" form:"stime"`
}

func (DeviceInformation) TableName() string {

	return "xt_device_information"
}

type DeviceCultures struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SpelingDate       int64  `gorm:"column:speling_date" json:"speling_date" form:"speling_date"`
	Specimen          int64  `gorm:"column:specimen" json:"specimen" form:"specimen"`
	ConcentrateNoa    string `gorm:"column:concentrate_noa" json:"concentrate_noa" form:"concentrate_noa"`
	ConcentrateNob    string `gorm:"column:concentrate_nob" json:"concentrate_nob" form:"concentrate_nob"`
	SamplingLocationa int64  `gorm:"column:sampling_locationa" json:"sampling_locationa" form:"sampling_locationa"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Sampler           int64  `gorm:"column:sampler" json:"sampler" form:"sampler"`
	ReportingDate     int64  `gorm:"column:reporting_date" json:"reporting_date" form:"reporting_date"`
	DetectionResult   string `gorm:"column:detection_result" json:"detection_result" form:"detection_result"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	UserName          string `gorm:"column:user_name" json:"user_name" form:"user_name"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

//细菌培养检测
type DeviceCulture struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SpelingDate       int64  `gorm:"column:speling_date" json:"speling_date" form:"speling_date"`
	Specimen          int64  `gorm:"column:specimen" json:"specimen" form:"specimen"`
	ConcentrateNoa    string `gorm:"column:concentrate_noa" json:"concentrate_noa" form:"concentrate_noa"`
	ConcentrateNob    string `gorm:"column:concentrate_nob" json:"concentrate_nob" form:"concentrate_nob"`
	SamplingLocationa int64  `gorm:"column:sampling_locationa" json:"sampling_locationa" form:"sampling_locationa"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Sampler           int64  `gorm:"column:sampler" json:"sampler" form:"sampler"`
	ReportingDate     int64  `gorm:"column:reporting_date" json:"reporting_date" form:"reporting_date"`
	DetectionResult   string `gorm:"column:detection_result" json:"detection_result" form:"detection_result"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (DeviceCulture) TableName() string {

	return "xt_device_culture"
}

type DeviceDialysates struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	UserName          string `gorm:"column:user_name" json:"user_name" form:"user_name"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

//内霉素检测
type DeviceDialysate struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (DeviceDialysate) TableName() string {

	return "xt_device_dialysate"
}

type DeviceIons struct {
	ID              int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate    int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Samplerc        int64  `gorm:"column:samplerc" json:"samplerc" form:"samplerc"`
	DetectionUnit   string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	ConcentrateNof  string `gorm:"column:concentrate_nof" json:"concentrate_nof" form:"concentrate_nof"`
	ConcentrateNog  string `gorm:"column:concentrate_nog" json:"concentrate_nog" form:"concentrate_nog"`
	DateReportc     int64  `gorm:"column:date_reportc" json:"date_reportc" form:"date_reportc"`
	ActualNa        string `gorm:"column:actual_na" json:"actual_na" form:"actual_na"`
	ActualPna       string `gorm:"column:actual_pna" json:"actual_pna" form:"actual_pna"`
	ActualK         string `gorm:"column:actual_k" json:"actual_k" form:"actual_k"`
	ActualCa        string `gorm:"column:actual_ca" json:"actual_ca" form:"actual_ca"`
	ActualCi        string `gorm:"column:actual_ci" json:"actual_ci" form:"actual_ci"`
	ActualHco       string `gorm:"column:actual_hco" json:"actual_hco" form:"actual_hco"`
	ActualMg        string `gorm:"column:actual_mg" json:"actual_mg" form:"actual_mg"`
	ActualPh        string `gorm:"column:actual_ph" json:"actual_ph" form:"actual_ph"`
	Remakes         string `gorm:"column:remakes" json:"remakes" form:"remakes"`
	Status          int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId       int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime           int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime           int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId           int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId     int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	UserName        string `gorm:"column:user_name" json:"user_name" form:"user_name"`
	Bed             string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort            string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications   int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

//透析液离子浓度检测
type DeviceIon struct {
	ID              int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate    int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Samplerc        int64  `gorm:"column:samplerc" json:"samplerc" form:"samplerc"`
	DetectionUnit   string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	ConcentrateNof  string `gorm:"column:concentrate_nof" json:"concentrate_nof" form:"concentrate_nof"`
	ConcentrateNog  string `gorm:"column:concentrate_nog" json:"concentrate_nog" form:"concentrate_nog"`
	DateReportc     int64  `gorm:"column:date_reportc" json:"date_reportc" form:"date_reportc"`
	ActualNa        string `gorm:"column:actual_na" json:"actual_na" form:"actual_na"`
	ActualPna       string `gorm:"column:actual_pna" json:"actual_pna" form:"actual_pna"`
	ActualK         string `gorm:"column:actual_k" json:"actual_k" form:"actual_k"`
	ActualCa        string `gorm:"column:actual_ca" json:"actual_ca" form:"actual_ca"`
	ActualCi        string `gorm:"column:actual_ci" json:"actual_ci" form:"actual_ci"`
	ActualHco       string `gorm:"column:actual_hco" json:"actual_hco" form:"actual_hco"`
	ActualMg        string `gorm:"column:actual_mg" json:"actual_mg" form:"actual_mg"`
	ActualPh        string `gorm:"column:actual_ph" json:"actual_ph" form:"actual_ph"`
	Remakes         string `gorm:"column:remakes" json:"remakes" form:"remakes"`
	Status          int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId       int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime           int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime           int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId           int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId     int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed             string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort            string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications   int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (DeviceIon) TableName() string {

	return "xt_device_ion"
}

type DeviceRepairs struct {
	ID               int64  `gorm:"column:id" json:"id" form:"id"`
	GuaranteeDate    int64  `gorm:"column:guarantee_date" json:"guarantee_date" form:"guarantee_date"`
	StartTime        int64  `gorm:"column:start_time" json:"start_time" form:"start_time"`
	ArriveTime       int64  `gorm:"column:arrive_time" json:"arrive_time" form:"arrive_time"`
	FinishTime       int64  `gorm:"column:finish_time" json:"finish_time" form:"finish_time"`
	TotalDistance    string `gorm:"column:total_distance" json:"total_distance" form:"total_distance"`
	FailureStage     int64  `gorm:"column:failure_stage" json:"failure_stage" form:"failure_stage"`
	FaultDescription string `gorm:"column:fault_description" json:"fault_description" form:"fault_description"`
	CauseAnalysis    string `gorm:"column:cause_analysis" json:"cause_analysis" form:"cause_analysis"`
	TreatmentProcess string `gorm:"column:treatment_process" json:"treatment_process" form:"treatment_process"`
	Images           string `gorm:"column:images" json:"images" form:"images"`
	Exclude          int64  `gorm:"column:exclude" json:"exclude" form:"exclude"`
	Reason           string `gorm:"column:reason" json:"reason" form:"reason"`
	Ctime            int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId        int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	BedId            int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId      int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	CodeInformation  string `gorm:"column:code_information" json:"code_information" form:"code_information"`
	Number           string `gorm:"column:number" json:"bed_number" form:"number"`
}

type DeviceRepair struct {
	ID               int64  `gorm:"column:id" json:"id" form:"id"`
	GuaranteeDate    int64  `gorm:"column:guarantee_date" json:"guarantee_date" form:"guarantee_date"`
	StartTime        int64  `gorm:"column:start_time" json:"start_time" form:"start_time"`
	ArriveTime       int64  `gorm:"column:arrive_time" json:"arrive_time" form:"arrive_time"`
	FinishTime       int64  `gorm:"column:finish_time" json:"finish_time" form:"finish_time"`
	TotalDistance    string `gorm:"column:total_distance" json:"total_distance" form:"total_distance"`
	FailureStage     int64  `gorm:"column:failure_stage" json:"failure_stage" form:"failure_stage"`
	FaultDescription string `gorm:"column:fault_description" json:"fault_description" form:"fault_description"`
	CauseAnalysis    string `gorm:"column:cause_analysis" json:"cause_analysis" form:"cause_analysis"`
	TreatmentProcess string `gorm:"column:treatment_process" json:"treatment_process" form:"treatment_process"`
	Images           string `gorm:"column:images" json:"images" form:"images"`
	Exclude          int64  `gorm:"column:exclude" json:"exclude" form:"exclude"`
	Reason           string `gorm:"column:reason" json:"reason" form:"reason"`
	Ctime            int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime            int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status           int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId        int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	BedId            int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId      int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	CodeInformation  string `gorm:"column:code_information" json:"code_information" form:"code_information"`
	ImageName        string `gorm:"column:image_name" json:"image_name" form:"image_name"`
}

func (DeviceRepair) TableName() string {

	return "xt_device_repair"
}

type XtAssessmentAfterDislysis struct {
	ID                              int64   `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                       int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId                       int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	AssessmentDate                  int64   `gorm:"column:assessment_date" json:"assessment_date" form:"assessment_date"`
	DialysisOrderId                 int64   `gorm:"column:dialysis_order_id" json:"dialysis_order_id" form:"dialysis_order_id"`
	Temperature                     float64 `gorm:"column:temperature" json:"temperature" form:"temperature"`
	PulseFrequency                  float64 `gorm:"column:pulse_frequency" json:"pulse_frequency" form:"pulse_frequency"`
	BreathingRate                   float64 `gorm:"column:breathing_rate" json:"breathing_rate" form:"breathing_rate"`
	SystolicBloodPressure           float64 `gorm:"column:systolic_blood_pressure" json:"systolic_blood_pressure" form:"systolic_blood_pressure"`
	DiastolicBloodPressure          float64 `gorm:"column:diastolic_blood_pressure" json:"diastolic_blood_pressure" form:"diastolic_blood_pressure"`
	BloodPressureType               int64   `gorm:"column:blood_pressure_type" json:"blood_pressure_type" form:"blood_pressure_type"`
	ActualUltrafiltration           float64 `gorm:"column:actual_ultrafiltration" json:"actual_ultrafiltration" form:"actual_ultrafiltration"`
	ActualDisplacement              float64 `gorm:"column:actual_displacement" json:"actual_displacement" form:"actual_displacement"`
	ActualTreatmentHour             int64   `gorm:"column:actual_treatment_hour" json:"actual_treatment_hour" form:"actual_treatment_hour"`
	ActualTreatmentMinute           int64   `gorm:"column:actual_treatment_minute" json:"actual_treatment_minute" form:"actual_treatment_minute"`
	WeighingWay                     string  `gorm:"column:weighing_way" json:"weighing_way" form:"weighing_way"`
	WeightAfter                     float64 `gorm:"column:weight_after" json:"weight_after" form:"weight_after"`
	AdditionalWeight                float64 `gorm:"column:additional_weight" json:"additional_weight" form:"additional_weight"`
	WeightLoss                      float64 `gorm:"column:weight_loss" json:"weight_loss" form:"weight_loss"`
	Cruor                           string  `gorm:"column:cruor" json:"cruor" form:"cruor"`
	SymptomAfterDialysis            string  `gorm:"column:symptom_after_dialysis" json:"symptom_after_dialysis" form:"symptom_after_dialysis"`
	InternalFistula                 string  `gorm:"column:internal_fistula" json:"internal_fistula" form:"internal_fistula"`
	Catheter                        string  `gorm:"column:catheter" json:"catheter" form:"catheter"`
	Complication                    string  `gorm:"column:complication" json:"complication" form:"complication"`
	Evaluator                       int64   `gorm:"column:evaluator" json:"evaluator" form:"evaluator"`
	Remark                          string  `gorm:"column:remark" json:"remark" form:"remark"`
	DialysisIntakes                 int64   `gorm:"column:dialysis_intakes" json:"dialysis_intakes" form:"dialysis_intakes"`
	DialysisIntakesFeed             int64   `gorm:"column:dialysis_intakes_feed" json:"dialysis_intakes_feed" form:"dialysis_intakes_feed"`
	DialysisIntakesTransfusion      int64   `gorm:"column:dialysis_intakes_transfusion" json:"dialysis_intakes_transfusion" form:"dialysis_intakes_transfusion"`
	DialysisIntakesBloodTransfusion int64   `gorm:"column:dialysis_intakes_blood_transfusion" json:"dialysis_intakes_blood_transfusion" form:"dialysis_intakes_blood_transfusion"`
	DialysisIntakesWashpipe         int64   `gorm:"column:dialysis_intakes_washpipe" json:"dialysis_intakes_washpipe" form:"dialysis_intakes_washpipe"`
	Status                          int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                     int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                     int64   `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	Creater                         int64   `gorm:"column:creater" json:"creater" form:"creater"`
	Modifier                        int64   `gorm:"column:modifier" json:"modifier" form:"modifier"`
	BloodAccessPartId               int64   `gorm:"column:blood_access_part_id" json:"blood_access_part_id" form:"blood_access_part_id"`
	BloodAccessPartOperaId          int64   `gorm:"column:blood_access_part_opera_id" json:"blood_access_part_opera_id" form:"blood_access_part_opera_id"`
	PuncturePointOozingBlood        int64   `gorm:"column:puncture_point_oozing_blood" json:"puncture_point_oozing_blood" form:"puncture_point_oozing_blood"`
	PuncturePointHaematoma          int64   `gorm:"column:puncture_point_haematoma" json:"puncture_point_haematoma" form:"puncture_point_haematoma"`
	InternalFistulaTremorAc         int64   `gorm:"column:internal_fistula_tremor_ac" json:"internal_fistula_tremor_ac" form:"internal_fistula_tremor_ac"`
	PatientGose                     int64   `gorm:"column:patient_gose" json:"patient_gose" form:"patient_gose"`
	InpatientDepartment             string  `gorm:"column:inpatient_department" json:"inpatient_department" form:"inpatient_department"`
	ObservationContent              string  `gorm:"column:observation_content" json:"observation_content" form:"observation_content"`
	ObservationContentOther         string  `gorm:"column:observation_content_other" json:"observation_content_other" form:"observation_content_other"`
	DryWeight                       float64 `gorm:"column:dry_weight" json:"dry_weight" form:"dry_weight"`
	DialysisProcess                 int64   `gorm:"column:dialysis_process" json:"dialysis_process" form:"dialysis_process"`
	InAdvanceMinute                 float64 `gorm:"column:in_advance_minute" json:"in_advance_minute" form:"in_advance_minute"`
	InAdvanceReason                 string  `gorm:"column:in_advance_reason" json:"in_advance_reason" form:"in_advance_reason"`
	HemostasisMinute                int64   `gorm:"column:hemostasis_minute" json:"hemostasis_minute" form:"hemostasis_minute"`
	HemostasisOpera                 int64   `gorm:"column:hemostasis_opera" json:"hemostasis_opera" form:"hemostasis_opera"`
	TremorNoise                     int64   `gorm:"column:tremor_noise" json:"tremor_noise" form:"tremor_noise"`
	DisequilibriumSyndrome          int64   `gorm:"column:disequilibrium_syndrome" json:"disequilibrium_syndrome" form:"disequilibrium_syndrome"`
	DisequilibriumSyndromeOption    string  `gorm:"column:disequilibrium_syndrome_option" json:"disequilibrium_syndrome_option" form:"disequilibrium_syndrome_option"`
	ArterialTube                    int64   `gorm:"column:arterial_tube" json:"arterial_tube" form:"arterial_tube"`
	IntravenousTube                 int64   `gorm:"column:intravenous_tube" json:"intravenous_tube" form:"intravenous_tube"`
	Dialyzer                        int64   `gorm:"column:dialyzer" json:"dialyzer" form:"dialyzer"`
	InAdvanceReasonOther            string  `gorm:"column:in_advance_reason_other" json:"in_advance_reason_other" form:"in_advance_reason_other"`
	AssessmentDoctor                int64   `gorm:"column:assessment_doctor" json:"assessment_doctor" form:"assessment_doctor"`
	AssessmentTime                  int64   `gorm:"column:assessment_time" json:"assessment_time" form:"assessment_time"`
	IsEat                           int64   `gorm:"column:is_eat" json:"is_eat" form:"is_eat"`
	DialysisIntakesUnit             int64   `gorm:"column:dialysis_intakes_unit" json:"dialysis_intakes_unit" form:"dialysis_intakes_unit"`
	CvcA                            float64 `gorm:"column:cvc_a" json:"cvc_a" form:"cvc_a"`
	CvcV                            float64 `gorm:"column:cvc_v" json:"cvc_v" form:"cvc_v"`
	Channel                         int64   `gorm:"column:channel" json:"channel" form:"channel"`
}

func (XtAssessmentAfterDislysis) TableName() string {

	return "xt_assessment_after_dislysis"
}

type DeviceRemander struct {
	ID        int64 `gorm:"column:id" json:"id" form:"id"`
	IsRun     int64 `gorm:"column:is_run" json:"is_run" form:"is_run"`
	UserOrgId int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status    int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime     int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime     int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
}

func (DeviceRemander) TableName() string {

	return "xt_device_remander"
}

type DeviceMode struct {
	ID         int64  `gorm:"column:id" json:"id" form:"id"`
	DeviceMode string `gorm:"column:device_mode" json:"device_mode" form:"device_mode"`
	Status     int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId  int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime      int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime      int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
}

func (DeviceMode) TableName() string {

	return "xt_device_mode"
}

type VmDeviceInformation struct {
	Total     int64
	BedNumber int64 `gorm:"column:bed_number" json:"bed_number" form:"bed_number"`
}

func (VmDeviceInformation) TableName() string {

	return "xt_device_information"
}

type VmSchedule struct {
	ScheduleDate int64  `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64  `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64  `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	BedId        int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	Partition    int64  `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	Name         string `gorm:"column:name" json:"name" form:"name"`
	Number       string `gorm:"column:number" json:"number" form:"number"`
	ZoneName     string `gorm:"column:name" json:"zon_name" form:"name"`
}

type XtDeviceOxygenates struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (XtDeviceOxygenates) TableName() string {

	return "xt_device_oxygenates"
}

type XtDeviceHadwater struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (XtDeviceHadwater) TableName() string {

	return "xt_device_hadwater"
}

type XtDeviceWater struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (XtDeviceWater) TableName() string {

	return "xt_device_water"
}

type XtDevicePh struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	SamplingDate      int64  `gorm:"column:sampling_date" json:"sampling_date" form:"sampling_date"`
	Specimenb         int64  `gorm:"column:specimenb" json:"specimenb" form:"specimenb"`
	ConcentrateNoc    string `gorm:"column:concentrate_noc" json:"concentrate_noc" form:"concentrate_noc"`
	ConcentratebNod   string `gorm:"column:concentrateb_nod" json:"concentrateb_nod" form:"concentrateb_nod"`
	SamplingLocationb int64  `gorm:"column:sampling_locationb" json:"sampling_locationb" form:"sampling_locationb"`
	DetectionUnit     string `gorm:"column:detection_unit" json:"detection_unit" form:"detection_unit"`
	Samplerb          int64  `gorm:"column:samplerb" json:"samplerb" form:"samplerb"`
	ReportingDateb    int64  `gorm:"column:reporting_dateb" json:"reporting_dateb" form:"reporting_dateb"`
	DetectionResultb  string `gorm:"column:detection_resultb" json:"detection_resultb" form:"detection_resultb"`
	Status            int64  `gorm:"column:status" json:"status" form:"status"`
	UserOrgId         int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime             int64  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime             int64  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	BedId             int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	EquitmentId       int64  `gorm:"column:equitment_id" json:"equitment_id" form:"equitment_id"`
	Bed               string `gorm:"column:bed" json:"bed" form:"bed"`
	Sort              string `gorm:"column:sort" json:"sort" form:"sort"`
	PassExamination   int64  `gorm:"column:pass_examination" json:"pass_examination" form:"pass_examination"`
	Modifications     int64  `gorm:"column:modifications" json:"modifications" form:"modifications"`
}

func (XtDevicePh) TableName() string {

	return "xt_device_ph"
}

type XtRemindPrintSetting struct {
	ID                     int64 `gorm:"column:id" json:"id" form:"id"`
	PrescriptionStatus     int64 `gorm:"column:prescription_status" json:"prescription_status" form:"prescription_status"`
	Week                   int64 `gorm:"column:week" json:"week" form:"week"`
	Name                   int64 `gorm:"column:name" json:"name" form:"name"`
	Zone                   int64 `gorm:"column:zone" json:"zone" form:"zone"`
	Classes                int64 `gorm:"column:classes" json:"classes" form:"classes"`
	Number                 int64 `gorm:"column:number" json:"number" form:"number"`
	Mode                   int64 `gorm:"column:mode" json:"mode" form:"mode"`
	Dialyzers              int64 `gorm:"column:dialyzers" json:"dialyzers" form:"dialyzers"`
	PerfusionApparatus     int64 `gorm:"column:perfusion_apparatus" json:"perfusion_apparatus" form:"perfusion_apparatus"`
	Anticoagulant          int64 `gorm:"column:anticoagulant" json:"anticoagulant" form:"anticoagulant"`
	DoctorAdvice           int64 `gorm:"column:doctor_advice" json:"doctor_advice" form:"doctor_advice"`
	UserOrgId              int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status                 int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime                  int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                  int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	AnticoagulantZongliang int64 `gorm:"column:anticoagulant_zongliang" json:"anticoagulant_zongliang" form:"anticoagulant_zongliang"`
}

func (XtRemindPrintSetting) TableName() string {

	return "xt_remind_print_setting"
}

type VmXtSchedule struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	Count        int64
}
